//==============================================================================
//
//   GraffitiInternalFrame.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: GraffitiInternalFrame.java,v 1.3 2003/10/31 16:38:54 forster Exp $

package org.graffiti.editor;

import org.graffiti.plugin.view.View;

import org.graffiti.session.EditorSession;

import org.graffiti.util.MaximizeFrame;

/**
 * A specialized internal frame for the graffiti editor. A
 * <code>GraffitiInternalFrame</code> is always resizable, closeable,
 * maximizable and iconifyable.
 *
 * @see javax.swing.JInternalFrame
 * @see MainFrame
 */
public class GraffitiInternalFrame
    extends MaximizeFrame
{
    //~ Instance fields ========================================================

    /** The session this frame is in. */
    private EditorSession session;

    /** The view this frame contains. */
    private View view;

    /** The number of this internal frame. */
    private int frameNumber;

    //~ Constructors ===========================================================

    /**
     * Constructs a new <code>GraffitiInternalFrame</code>.
     */
    public GraffitiInternalFrame()
    {
        super();
        this.setMaximizable(true);
        this.setClosable(true);
        this.setResizable(true);
        this.setIconifiable(true);

        GraffitiSingleton.getInstance().addFrame(this);
    }

    /**
     * Constructor that sets the session, as well as the title.
     *
     * @param session the session this frame is in.
     * @param view DOCUMENT ME!
     * @param title the title of this internal frame.
     */
    public GraffitiInternalFrame(EditorSession session, View view, String title)
    {
        this();
        this.session = session;
        this.view = view;
        frameNumber = session.getViews().size() + 1;
        setTitle(title);
    }

    //~ Methods ================================================================

    /**
     * Returns the session this frame is opened in.
     *
     * @return the session this frame is opened in.
     */
    public EditorSession getSession()
    {
        return session;
    }

    /**
     * Sets the title of this frame and its associated button and menu button.
     *
     * @param title the new title of the frame.
     */
    public void setTitle(String title)
    {
        String frameTitle = title + " - " + frameNumber;

        super.setTitle(frameTitle);
    }

    /**
     * Returns the view of this frame.
     *
     * @return the view of this frame.
     */
    public View getView()
    {
        return view;
    }
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
