//==============================================================================
//
//   FileOpenAction.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: FileOpenAction.java,v 1.7 2004/03/31 13:21:55 klukas Exp $

package org.graffiti.editor.actions;

import java.awt.event.ActionEvent;

import java.io.File;

import javax.swing.JFileChooser;

import org.graffiti.core.GenericFileFilter;
import org.graffiti.core.StringBundle;

import org.graffiti.editor.MainFrame;

import org.graffiti.help.HelpContext;

import org.graffiti.managers.IOManager;
import org.graffiti.managers.ViewManager;

import org.graffiti.plugin.actions.GraffitiAction;

/**
 * The action for the file open dialog.
 */
public class FileOpenAction
    extends GraffitiAction
{
    //~ Instance fields ========================================================

    /** DOCUMENT ME! */
    private IOManager ioManager;

    /** DOCUMENT ME! */
    private StringBundle sBundle;

    /** DOCUMENT ME! */
    private ViewManager viewManager;

    //~ Constructors ===========================================================

    /**
     * Creates a new FileOpenAction object.
     *
     * @param mainFrame DOCUMENT ME!
     * @param ioManager DOCUMENT ME!
     * @param viewManager DOCUMENT ME!
     * @param sBundle DOCUMENT ME!
     */
    public FileOpenAction(MainFrame mainFrame, IOManager ioManager,
        ViewManager viewManager, StringBundle sBundle)
    {
        super("file.open", mainFrame);
        this.ioManager = ioManager;
        this.viewManager = viewManager;
        this.sBundle = sBundle;
    }

    //~ Methods ================================================================

    /**
     * This action is enabled, if the editor's io manager contains an input
     * serializer.
     *
     * @return <code>true</code>, if the io manager contains at least one input
     *         serializer.
     */
    public boolean isEnabled()
    {
        return ioManager.hasInputSerializer() && viewManager.hasViews();
    }

    /**
     * @see org.graffiti.plugin.actions.GraffitiAction#getHelpContext()
     */
    public HelpContext getHelpContext()
    {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void actionPerformed(ActionEvent e)
    {
        JFileChooser fc = ioManager.createOpenFileChooser();

        //      fc.resetChoosableFileFilters();
        int returnVal = fc.showDialog(mainFrame,
                sBundle.getString("menu.file.open"));

        if(returnVal == JFileChooser.APPROVE_OPTION)
        {
            File file = fc.getSelectedFile();

            if(file.getName().indexOf(".") == -1)
            {
                String extension = ((GenericFileFilter) fc.getFileFilter()).getExtension();
                file = new File(file + extension);
            }

            mainFrame.loadGraph(file);
            if (mainFrame!=null && mainFrame.getActiveSession()!=null 
            	&& mainFrame.getActiveSession().getGraph()!=null)
            	mainFrame.getActiveSession().getGraph().setModified(false);
        }
    }
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
