//==============================================================================
//
//   FileSaveAsAction.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: FileSaveAsAction.java,v 1.4 2004/01/26 11:00:23 klukas Exp $

package org.graffiti.editor.actions;

import java.awt.event.ActionEvent;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import javax.swing.JFileChooser;
import javax.swing.JOptionPane;

import org.graffiti.core.GenericFileFilter;
import org.graffiti.core.StringBundle;

import org.graffiti.editor.MainFrame;

import org.graffiti.help.HelpContext;

import org.graffiti.managers.IOManager;

import org.graffiti.plugin.actions.GraffitiAction;
import org.graffiti.plugin.io.OutputSerializer;
import org.graffiti.plugin.view.MessageListener;

import org.graffiti.session.EditorSession;
import org.graffiti.session.SessionManager;

/**
 * The action for saving a graph to a named file.
 *
 * @version $Revision: 1.4 $
 */
public class FileSaveAsAction
    extends GraffitiAction
{
    //~ Instance fields ========================================================

    /** DOCUMENT ME! */
    private IOManager ioManager;

    /** DOCUMENT ME! */
    private SessionManager sessionManager;

    /** DOCUMENT ME! */
    private StringBundle sBundle;

    //~ Constructors ===========================================================

    //    private JFileChooser fc;
    public FileSaveAsAction(MainFrame mainFrame, IOManager ioManager,
        SessionManager sessionManager, StringBundle sBundle)
    {
        super("file.saveAs", mainFrame);
        this.ioManager = ioManager;
        this.sessionManager = sessionManager;
        this.sBundle = sBundle;

        //        fc = new JFileChooser();
    }

    //~ Methods ================================================================

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public boolean isEnabled()
    {
        return ioManager.hasOutputSerializer() &&
        sessionManager.isSessionActive();
    }

    /**
     * @see org.graffiti.plugin.actions.GraffitiAction#getHelpContext()
     */
    public HelpContext getHelpContext()
    {
        return null;
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void actionPerformed(ActionEvent e)
    {
        JFileChooser fc = ioManager.createSaveFileChooser();

        boolean needFile = true;

        while(needFile)
        {
            int returnVal = fc.showDialog(mainFrame,
                    sBundle.getString("menu.file.saveAs"));

            if(returnVal == JFileChooser.APPROVE_OPTION)
            {
                File file = fc.getSelectedFile();
                String fileName = file.getName();

                //System.err.println(fileName);
                String ext = "";

                if(fileName.indexOf(".") == -1)
                {
                    ext = ((GenericFileFilter) fc.getFileFilter()).getExtension();
                    fileName = file.getName() + ext;
                    file = new File(file.getAbsolutePath() + ext);
                }
                else
                {
                    ext = fileName.substring(fileName.lastIndexOf("."));
                }

                //System.err.println(fileName);
                if(file.exists())
                {
                    if(JOptionPane.showConfirmDialog(mainFrame,
                            "Do you want to overwrite the existing file " +
                            fileName + "?", "Overwrite File?",
                            JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION)
                    {
                        needFile = false;
                    }
                }
                else
                {
                    needFile = false;
                }

                if(!needFile)
                {
                    try
                    {
                        OutputSerializer os = ioManager.createOutputSerializer(ext);

                        os.write(new FileOutputStream(file),
                            mainFrame.getActiveSession().getGraph());
                        mainFrame.getActiveSession().getGraph().setModified(false);
                    }
                    catch(IOException ioe)
                    {
                        mainFrame.showMesssage("Error: Could not save file.",
                            MessageListener.ERROR);
                        ioe.printStackTrace();

                        // todo: add exception handling
                    }
                    catch(IllegalAccessException iae)
                    {
                        mainFrame.showMesssage("Error: Could not save file.",
                            MessageListener.ERROR);
                        iae.printStackTrace(System.err);
                    }
                    catch(InstantiationException ie)
                    {
                        mainFrame.showMesssage("Error: Could not save file.",
                            MessageListener.ERROR);
                        ie.printStackTrace(System.err);
                    }

                    EditorSession session = (EditorSession) mainFrame.getActiveSession();

                    session.setFileName(file.toURI());
                    mainFrame.fireSessionDataChanged(session);
                }
            }
            else
            {
                // leave loop
                needFile = false;
            }
        }
    }
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
