//==============================================================================
//
//   RunAlgorithm.java
//
//   Copyright (c) 2001-2003 Graffiti Team, Uni Passau
//
//==============================================================================
// $Id: RunAlgorithm.java,v 1.7 2004/04/21 12:59:25 koschuet Exp $

package org.graffiti.editor.actions;

import java.awt.event.ActionEvent;

import org.graffiti.editor.GraffitiSingleton;
import org.graffiti.editor.MainFrame;

import org.graffiti.help.HelpContext;

import org.graffiti.managers.EditComponentManager;

import org.graffiti.plugin.actions.GraffitiAction;
import org.graffiti.plugin.algorithm.Algorithm;

/**
 * Runs an algorithm.
 *
 * @version $Revision: 1.7 $
 */
public class RunAlgorithm
    extends GraffitiAction
{
    //~ Instance fields ========================================================

    /** The edit component manager for the parameter edit panel. */
    private EditComponentManager editComponentManager;

    /** The class name of the algorithm to run. */
    private String algorithmClassName;
    
	private Algorithm algorithm;    

    //~ Constructors ===========================================================

    /**
     * Constructor for RunAlgorithm.
     *
     * @param algorithmClassName DOCUMENT ME!
     * @param name
     * @param mainFrame
     * @param editComponentManager DOCUMENT ME!
     */
    public RunAlgorithm(String algorithmClassName, String name,
        MainFrame mainFrame, EditComponentManager editComponentManager, Algorithm instance)
    {
        super(name, mainFrame);
        this.algorithmClassName = algorithmClassName;
        this.editComponentManager = editComponentManager;
		this.algorithm = instance;
    }

    //~ Methods ================================================================

    /**
     * Get the name of the algorithm that this action will run.
     *
     * @return the name of the algorithm that this action will run.
     */
    public String getAlgorithmClassName()
    {
        return algorithmClassName;
    }

    /**
     * @see javax.swing.Action#isEnabled()
     */
    public boolean isEnabled()
    {
        return mainFrame.isSessionActive();
    }

    /**
     * @see org.graffiti.plugin.actions.GraffitiAction#getHelpContext()
     */
    public HelpContext getHelpContext()
    {
        return null;
    }

    /**
     * @see java.awt.event.ActionListener#actionPerformed(ActionEvent)
     */
    public void actionPerformed(ActionEvent a)
    {
        GraffitiSingleton.runAlgorithm(algorithm);
    }
}

//------------------------------------------------------------------------------
//   end of file
//------------------------------------------------------------------------------
